==> kubernetes-model-flowcontrol-6.3.0-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta2/PriorityLevelConfigurationFluent.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta2;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PriorityLevelConfigurationFluent<A extends PriorityLevelConfigurationFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public PriorityLevelConfigurationFluent.MetadataNested<A> withNewMetadata();
  public PriorityLevelConfigurationFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public PriorityLevelConfigurationFluent.MetadataNested<A> editMetadata();
  public PriorityLevelConfigurationFluent.MetadataNested<A> editOrNewMetadata();
  public PriorityLevelConfigurationFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public PriorityLevelConfigurationSpec getSpec();
  public PriorityLevelConfigurationSpec buildSpec();
  public A withSpec(PriorityLevelConfigurationSpec spec);
  public Boolean hasSpec();
  public PriorityLevelConfigurationFluent.SpecNested<A> withNewSpec();
  public PriorityLevelConfigurationFluent.SpecNested<A> withNewSpecLike(PriorityLevelConfigurationSpec item);
  public PriorityLevelConfigurationFluent.SpecNested<A> editSpec();
  public PriorityLevelConfigurationFluent.SpecNested<A> editOrNewSpec();
  public PriorityLevelConfigurationFluent.SpecNested<A> editOrNewSpecLike(PriorityLevelConfigurationSpec item);
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public PriorityLevelConfigurationStatus getStatus();
  public PriorityLevelConfigurationStatus buildStatus();
  public A withStatus(PriorityLevelConfigurationStatus status);
  public Boolean hasStatus();
  public PriorityLevelConfigurationFluent.StatusNested<A> withNewStatus();
  public PriorityLevelConfigurationFluent.StatusNested<A> withNewStatusLike(PriorityLevelConfigurationStatus item);
  public PriorityLevelConfigurationFluent.StatusNested<A> editStatus();
  public PriorityLevelConfigurationFluent.StatusNested<A> editOrNewStatus();
  public PriorityLevelConfigurationFluent.StatusNested<A> editOrNewStatusLike(PriorityLevelConfigurationStatus item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<PriorityLevelConfigurationFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface SpecNested<N> extends Nested<N>,PriorityLevelConfigurationSpecFluent<PriorityLevelConfigurationFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  public interface StatusNested<N> extends Nested<N>,PriorityLevelConfigurationStatusFluent<PriorityLevelConfigurationFluent.StatusNested<N>>{
    public N and();
    public N endStatus();
    
  }
  
}

==> kubernetes-model-flowcontrol-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta2/PriorityLevelConfigurationFluent.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta2;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PriorityLevelConfigurationFluent<A extends PriorityLevelConfigurationFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public PriorityLevelConfigurationFluent.MetadataNested<A> withNewMetadata();
  public PriorityLevelConfigurationFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public PriorityLevelConfigurationFluent.MetadataNested<A> editMetadata();
  public PriorityLevelConfigurationFluent.MetadataNested<A> editOrNewMetadata();
  public PriorityLevelConfigurationFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public PriorityLevelConfigurationSpec getSpec();
  public PriorityLevelConfigurationSpec buildSpec();
  public A withSpec(PriorityLevelConfigurationSpec spec);
  public Boolean hasSpec();
  public PriorityLevelConfigurationFluent.SpecNested<A> withNewSpec();
  public PriorityLevelConfigurationFluent.SpecNested<A> withNewSpecLike(PriorityLevelConfigurationSpec item);
  public PriorityLevelConfigurationFluent.SpecNested<A> editSpec();
  public PriorityLevelConfigurationFluent.SpecNested<A> editOrNewSpec();
  public PriorityLevelConfigurationFluent.SpecNested<A> editOrNewSpecLike(PriorityLevelConfigurationSpec item);
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public PriorityLevelConfigurationStatus getStatus();
  public PriorityLevelConfigurationStatus buildStatus();
  public A withStatus(PriorityLevelConfigurationStatus status);
  public Boolean hasStatus();
  public PriorityLevelConfigurationFluent.StatusNested<A> withNewStatus();
  public PriorityLevelConfigurationFluent.StatusNested<A> withNewStatusLike(PriorityLevelConfigurationStatus item);
  public PriorityLevelConfigurationFluent.StatusNested<A> editStatus();
  public PriorityLevelConfigurationFluent.StatusNested<A> editOrNewStatus();
  public PriorityLevelConfigurationFluent.StatusNested<A> editOrNewStatusLike(PriorityLevelConfigurationStatus item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<PriorityLevelConfigurationFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  public interface SpecNested<N> extends Nested<N>,PriorityLevelConfigurationSpecFluent<PriorityLevelConfigurationFluent.SpecNested<N>>{
    public N and();
    public N endSpec();
    
  }
  public interface StatusNested<N> extends Nested<N>,PriorityLevelConfigurationStatusFluent<PriorityLevelConfigurationFluent.StatusNested<N>>{
    public N and();
    public N endStatus();
    
  }
  
}
